.. toctree::
   :maxdepth: 2
   :caption: Contents:

   endpoint
   response
   request
   IPAM

TL;DR
=====
Instantiate the :py:class:`.Api`. Use the methods available on :py:class:`.Endpoint` to return :py:class:`.Record` objects. 

API
===

.. autoclass:: pynetbox.core.api.Api
  :members:

App
===

.. autoclass:: pynetbox.core.app.App
  :members:

Indices and tables
==================

* :ref:`genindex`
